@@ -1,22 +1,19 @@
 package SOAP::XML::Client;
-{
-  $SOAP::XML::Client::VERSION = '2.26';
-}
 
 use strict;
 use Carp;
-use XML::LibXML 0.6;
-use SOAP::Lite 0.67;
-use SOAP::Data::Builder 0.8;
+use XML::LibXML;
+use SOAP::Lite;
+use SOAP::Data::Builder;
 use File::Slurp;
 use Encode qw( decode );
 
-use vars qw($DEBUG);
+use vars qw($VERSION $DEBUG);
 
 use base qw(Class::Accessor::Fast);
 
 my @methods = qw(results results_xml uri xmlns proxy soapversion timeout error
-    strip_default_xmlns encoding header status);
+    strip_default_xmlns encoding header);
 
 # wsdk
 
@@ -24,6 +21,8 @@ __PACKAGE__->mk_accessors(@methods);
 
 $DEBUG = 0;
 
+$VERSION = 2.3;
+
 # Get an XML Parser
 my $parser = XML::LibXML->new();
 $parser->validation(0);
@@ -31,7 +30,7 @@ $parser->expand_entities(0);
 
 # which methods should be set on object constructor
 my @config_methods
-    = qw(uri xmlns proxy soapversion strip_default_xmlns encoding timeout);
+    = qw(uri xmlns proxy soapversion strip_default_xmlns encoding);
 
 sub new {
     my ( $proto, $conf ) = @_;
@@ -56,11 +55,7 @@ sub new {
         *SOAP::Serializer::as_base64Binary = sub {
             my $self = shift;
             my ( $value, $name, $type, $attr ) = @_;
-            return [
-                $name,
-                { 'xsi:type' => 'xsd:string', %$attr },
-                SOAP::Utils::encode_data($value)
-            ];
+            return [ $name, { 'xsi:type' => 'xsd:string', %$attr }, $value ];
         };
     }
 
@@ -173,16 +168,14 @@ sub fetch {
 #print Dumper($self->{sdb}->elems());
 
     # execute the call in the relevant style done by the child object
-    my ( $res, $transport ) = $self->_call( $conf->{method} );
-
-    $self->status( $transport->status );
+    my $res = $self->_call( $conf->{method} );
 
 # TODO: actually need to specify encoding expected in return (or parse from response?)
     $res = decode( $self->{encoding}, $res );
 
     carp "After run _call()" if $DEBUG;
 
-    if ( !defined $res or $res =~ /^\d/ or !$transport->is_success ) {
+    if ( !defined $res or $res =~ /^\d/ ) {
 
         # Got a web error - if it was XML it wouldn't start with a digit!
         $self->error($res);
@@ -199,7 +192,7 @@ sub fetch {
         if ($@) {
 
             # Not valid xml
-            $self->error( 'Unable to parse returned data as XML: ' . $@ );
+            $self->error('Unable to parse returned data as XML');
             return undef;
         } else {
 
@@ -418,7 +411,6 @@ credential based authenditcation
   } else {
       # There was some sort of error
       print $soap_client->error() . "\n";
-      print "Status: " . $soap_client->status();
   }
 
 This method actually calls the web service, it takes a method name
@@ -445,12 +437,6 @@ supplied couldn't be read, the XML you supplied was not correctly formatted (XML
 could not parse it), there was a transport error with the web service or Fault/faultstring
 was found in the XML returned.
 
-=head2 status()
-
-  $soap_client->status();
-  
-This is set to the http status after fetch has been called
-
 =head2 results();
 
   my $results = $soap_client->results();
@@ -548,6 +534,13 @@ Leo Lapworth <LLAP@cuckoo.org>
 
 http://github.com/ranguard/soap-xml-client
 
+=head1 COPYRIGHT
+
+(c) 2005 Leo Lapworth
+
+This library is free software, you can use it under the same 
+terms as perl itself.
+
 =head1 THANKS
 
 Thanks to Foxtons for letting me develope this on their time and
